"""DO NOT MODIFY. Auto-generated by script/fingerprint_frontend."""

FINGERPRINTS = {
    "core.js": "1f7f88d8f5dada08bce1d935cfa5f33e",
    "frontend.html": "a179cbf60629f02e1d6f4b0034a783bf",
    "mdi.html": "c1dde43ccf5667f687c418fc8daf9668",
    "micromarkdown-js.html": "93b5ec4016f0bba585521cf4d18dec1a",
    "panels/ha-panel-dev-event.html": "5c82300b3cf543a92cf4297506e450e7",
    "panels/ha-panel-dev-info.html": "5f8119c8aa18cba51106e1bb8ca9cba2",
    "panels/ha-panel-dev-service.html": "306243e11766266c967d1163ca678fe6",
    "panels/ha-panel-dev-state.html": "7d069ba8fd5379fa8f59858b8c0a7473",
    "panels/ha-panel-dev-template.html": "219d66c469982b6d6ae015d21156ac82",
    "panels/ha-panel-history.html": "c5cf0aa3eba31f40231b0479b08913eb",
    "panels/ha-panel-iframe.html": "d920f0aa3c903680f2f8795e2255daab",
    "panels/ha-panel-logbook.html": "2af1feb30b37427f481d5437a438a3f2",
    "panels/ha-panel-map.html": "ecd2ee7ff6e2837e67950d3ab1a6ec65",
    "websocket_test.html": "575de64b431fe11c3785bf96d7813450"
}



"""
Support for Wink switches.

For more details about this platform, please refer to the documentation at
https://home-assistant.io/components/switch.wink/
"""

from homeassistant.components.wink import WinkDevice, DOMAIN
from homeassistant.helpers.entity import ToggleEntity

DEPENDENCIES = ['wink']


def setup_platform(hass, config, add_devices, discovery_info=None):
    """Setup the Wink platform."""
    import pywink

    for switch in pywink.get_switches():
        _id = switch.object_id() + switch.name()
        if _id not in hass.data[DOMAIN]['unique_ids']:
            add_devices([WinkToggleDevice(switch, hass)])
    for switch in pywink.get_powerstrips():
        _id = switch.object_id() + switch.name()
        if _id not in hass.data[DOMAIN]['unique_ids']:
            add_devices([WinkToggleDevice(switch, hass)])
    for switch in pywink.get_sirens():
        _id = switch.object_id() + switch.name()
        if _id not in hass.data[DOMAIN]['unique_ids']:
            add_devices([WinkToggleDevice(switch, hass)])
    for sprinkler in pywink.get_sprinklers():
        _id = sprinkler.object_id() + sprinkler.name()
        if _id not in hass.data[DOMAIN]['unique_ids']:
            add_devices([WinkToggleDevice(sprinkler, hass)])


class WinkToggleDevice(WinkDevice, ToggleEntity):
    """Representation of a Wink toggle device."""

    def __init__(self, wink, hass):
        """Initialize the Wink device."""
        super().__init__(wink, hass)

    @property
    def is_on(self):
        """Return true if device is on."""
        return self.wink.state()

    def turn_on(self, **kwargs):
        """Turn the device on."""
        self.wink.set_state(True)

    def turn_off(self):
        """Turn the device off."""
        self.wink.set_state(False)

    @property
    def device_state_attributes(self):
        """Return the state attributes."""
        try:
            event = self.wink.last_event()
        except AttributeError:
            event = None
        return {
            'last_event': event
        }
